/*

=head1 NAME

languid.js - JavaScript interface to the languid.cantbedone.org API

=head1 SYNOPSIS

   # you'll need to do this under Mozilla/Gecko (but not Safari)        
   # netscape.security.PrivilegeManager.enablePrivilege("UniversalBrowserRead");

   # Get some chunk of text, for example a
   # part of the current document.

   var input = document.getElementById("input");
   var txt   = input.firstChild.nodeValue;

   var lang   = new Languid();
   var ident  = lang.identify(txt);
   var result = null;

   # My kingdom for a built-in sprintf function...

   if (ident.success()) {
      	result = ident + " (" + ident.code() + ")";
   } 

   else {
        result = "error : " + ident.err() + ", " + ident.errstr();
   }

   # Set 'result' as the string value of some other
   # part of the current document.

   var languid = document.getElementById("languid");
   languid.innerHTML = result;

=head1 DESCRIPTION

JavaScript interface to the languid.cantbedone.org API. This library is
B<not> asynchronous. 

=cut

=head1 Languid CLASS METHODS

=head2 new Languid ()

Returns a I<Languid> object.

=cut

*/

function Languid () {
    this.inheritFrom = Object;
    this.inheritFrom();

    this._ua  = null;
    this._api = "http://languid.cantbedone.org/api/0.1";

    this.VERSION = '1.0';
}

/*

=head1 Languid OBJECT METHODS

=head2 obj.languid(String)

Returns an I<Response> object.

=cut

*/

Languid.prototype.identify = function (txt) {

    req = this._api + "?text=" + txt;
    ua  = this._agent();

    if (! ua) {
	return new Error(500,
			 "Unable to create XMLHttpRequest object");
    }

    ua.open("GET",req,false);
    ua.send(null);

    // alert(ua.responseText);
    // alert(ua.responseXML);

    if (ua.status != 200) {
	return new Error(ua.status,
			 ua.statusText);
    }

    var doc = ua.responseXML;
    var err = doc.getElementsByTagName("error")[0];

    if (err) {
	return new Error(err.getAttribute("code"));
    }

    var lang = doc.getElementsByTagName("language")[0];

    if (! lang) {
	return new Error(500,
			 "Unable to determine response for " + 
			  ua.responseText);
    }

    return new Language(lang.getAttribute("iso"),
			lang.getAttribute("name"));
}

Languid.prototype._agent = function () {

    if (this._ua != null) {
	return this._ua;
    }

    var xmlhttp = null;

    /*@cc_on @*/
    /*@if (@_jscript_version >= 5)

    // JScript gives us Conditional compilation, we can cope with old IE versions.
    // and security blocked creation of the objects.

    try {
       xmlhttp = new ActiveXObject("Msxml2.XMLHTTP");
    } 

    catch (e) {
       try {
          xmlhttp = new ActiveXObject("Microsoft.XMLHTTP");
       } 

       catch (E) {
          return null;
       }
    }

    @end @*/

    if ((! xmlhttp) && (typeof(XMLHttpRequest) != 'undefined')) {
	xmlhttp = new XMLHttpRequest();
    }

    if (xmlhttp != null) {
        this._ua = xmlhttp;
    }

    return this._ua;
}

/*

=head1 Resposne OBJECT METHODS

A I<Response> object's toString() method is set up to return the
string value of the language identifier.

 var languid = new Languid();
 var ident   = languid.identify("some english text");

 # prints "language is english" if successful
 # prints "language is "        if not

 alert("language is " + ident);

=head2 obj.success()

Returns true or false.

=head2 obj.code() 

Returns an ISO code identifying the language result.

=head2 obj.err()

Returns the error code associated with a failed request.

=head2 obj.errstr()

Returns an optional error string associated with a failed
request.

=cut

*/

function Language(code,str) {
    this.inheritFrom = Response;
    this.inheritFrom(code,str);

    this.code = function () {
	return this._code;
    }

    this.toString = function () {
	return this._str;
    }
}

function Error (code,str) {
    this.inheritFrom = Response;
    this.inheritFrom(code,str);

    this.success = function () {
	return false;
    }

    this.err = function () {
	return this._code;
    }

    this.errstr = function () {
	return this._str;
    }
}

function Response (code,str) {
    this.inheritFrom = Object;
    this.inheritFrom();

    this._code = code;
    this._str  = str;

    this.success = function () {
	return true;
    }

    this.code = function () {
	return undefined;
    }

    this.err = function () {
	return undefine;
    }

    this.errstr = function () {
	return undefined;
    }

    this.toString = function () {
	return "";
    }
}

/*

=head1 VERSION

1.0

=head1 DATE

$Date: 2004/11/17 16:52:13 $

=head1 AUTHOR

Aaron Straup Cope

=head1 SEE ALSO

http://languid.cantbedone.org

=head1 LICENSE

Copyright (c) 2004 Aaron Straup Cope. All Rights Reserved.

This is free software, you may use it and distribute it under
the same terms as the Perl Artistic License.

=cut

$Id: languid.js,v 1.6 2004/11/17 16:52:13 asc Exp $

*/
